<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="robots" content="noindex">
    <title>Index of {{ page_name }}</title>
</head>
<body>
<h1>Index of {{ page_name }}</h1>
<pre>{{ table_headers }}</pre>
<hr/>
<pre>
{% if not_root %}<a href="../" class="parent_link">../</a></br>{% endif %}
{% for index_item in index_items %}
<a href="{{ index_item.encoded_name }}" class="item_link">{{ index_item.name }}</a>{{ index_item.name_padding }}{{ index_item.modified }}{{ index_item.size }}
{% endfor %}
</pre>
<hr/>
<address style="font-size:small;">Generated by <a href="https://github.com/hmrc/bucket-dir">bucket-dir</a>.</address>
</body>
</html>
